Clazz.declarePackage("JS");
Clazz.load(["JS.LayoutManager"], "JS.FlowLayout", null, function(){
var c$ = Clazz.declareType(JS, "FlowLayout", JS.LayoutManager);
});
;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
